#
# spec file for package python-pygn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pygn
Version:        0.12.0
Release:        1.2
Summary:        The Python Gateway Script: news2mail mail2news gateway
License:        GPL-3.0-only
Group:          Productivity/Networking/News/Utilities
URL:            https://git.sr.ht/~mcepl/pygn
Source:         https://files.pythonhosted.org/packages/source/p/pygn/pygn-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pynntp if %python-base >= 3.12}
BuildRequires:  %{python_module rply}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-rply
Requires:       (python-pynntp if python-base >= 3.12)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Python Gateway Script from news to mail and vice versa.

It is intended to be a full SMTP/NNTP rfc compliant gateway
with whitelist manager.

You will probably have to install a mail-transport-agent and/or
news-transport-system package to manage SMTP/NNTP traffic.

MTA is needed for mail2news service, since mail have to be
processed on a box where pyg is installed. You can use a remote
smtpserver for news2mail.

News system is useful but not needed, since you can send articles to a
remote SMTP server (ie: moderated NG) where is installed pyg, otherwise you
will need it.

It refers to rfc 822 (mail) and 850 (news).

%prep
%autosetup -p1 -n pygn-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pygm2n
%python_clone -a %{buildroot}%{_bindir}/pygn2m
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v test

%post
%python_install_alternative pygm2n pygn2m

%postun
%python_uninstall_alternative pygm2n pygn2m

%files %{python_files}
%{python_sitelib}/mail2news.py
%{python_sitelib}/news2mail.py
%{python_sitelib}/whitelist.py
%{python_sitelib}/wlp.py
%{python_sitelib}/wlp_parser.py
%{python_sitelib}/pygn-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__/*.pyc
%python_alternative %{_bindir}/pygm2n
%python_alternative %{_bindir}/pygn2m

%changelog
* Wed Dec 11 2024 Matej Cepl <mcepl@cepl.eu>
- fix: change dependency from nntplib to pynntp
  - First attempt to create .build.yml script for builds.sr.ht
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Wed Jun 28 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.11.0:
  - Rewrite to new structure and abandoning setuptools
- Update to 0.10.3:
  - refactor: rearrange the project to the src/ layout
    (https://todo.sr.ht/~mcepl/pygn/7)
  - Fix also pyproject.toml to generate what seems right.
  - Add the explicit dependency on nntplib for Python >= 3.12
    (gh#python/cpython!104894).
  - Use email.policy.SMTP to be perfectly conforming with RFCs.
    Perhaps fixes: https://todo.sr.ht/~mcepl/pygn/6
  - Rename README to README.md
  - Switch hosting of the project to Sourcehut.
  - Also add the text of GPLv3.
  - When sending nntp message fails, log the message to temporary
    file.
  - Convert documentation from .maff to plain HTML.
  - Parse email messages from binary files (Fixes #24
    on GitLab (see also gh#python/cpython#69731 and
    gh#python/cpython#85479)
- We actually don't need pytest.
* Wed Nov 30 2022 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file, make rpmlint happy.
* Wed Jul  1 2020 Matej Cepl <mcepl@suse.com>
- Update to 0.10.2:
  - Fix packaging, switch off failing tests for now.
* Wed Jul  1 2020 Matej Cepl <mcepl@suse.com>
- Initial packaging effort
